function [sigma] = CalcSigfromM(D,mech);
%
%	function sigma = CalcSigM(D,'mech') calculates
%	the slip variation around the mean given by the
%	rupture dimensions and the moment of the rupturing fault
%	The actual value is picked from a normal distribution 
%	within the error bounds of measured sig. vs. Mo
%
%	input:	D   	- mean slip (in meters!)
%	      	mech 	- 'ss' or 'SS' for strike-slip events; 
%			  'ds' or 'DS' for dip-slip events
%			  'al' or 'AL' for all events
%

%	Written by Martin Mai (mmai@pangea.Stanford.EDU) 
%	06/26/97
%	last change 08/23/99
%	------------------------------------------------


%%% constants derived from regression analysis
if ((mech == 'al') | (mech == 'AL'));
      ads = 0.7028;	bds = 9.8271;	vards = 19.4544;
elseif ((mech == 'ss') | (mech == 'SS')) ; 
      ads = 0.6759;     bds = 10.455;	vards = 16.9078;
elseif ((mech == 'ds') | (mech == 'DS')) ; 
      ads = 0.7378;    	bds = 8.2825;	vards = 22.8696;
end


%%% compute central value
sigmaS = ads*D + bds;


%%% pick sigma value from normal distribution
sigma = NormSample(sigmaS,0.5*vards,100);
