function [xi,NUseed] = NormSample(mu,sigma,N,NUseed)
%
%  [xi,NUseed] = NormSample(mu,sigma,N,NUseed) 
%  returns a sample xi randomly drawn from a normal 
%  distribution of random variables X with mean mu and 
%  standard deviation sigma. 
%  N is the length of the distribution to be considered,
%  NUseed can be a 2D-array for seed-values
%
%  INPUT:
%
%  mu	 - mean of random variable X (default: mu = 0)
%  sigma - standard deviation of X (default: sigma = 1)
%  N	 - length of distribution (default: N = 100)
%  NUseed- optional: 2D-array of seeds for random number generator
%
%  OUTPUT:
%
%  xi	 - random sample, chosen from a uniform distribution
%	   of length(N) to select the value of xi among all x
%  NUseed- returns the 'seeds' i.e. the state of the random
%	   number generators (needed in case one wants to
%	   exactly reproduce the results)

%  Written by Martin Mai (mmai@pangea.Stanford.EDU) 
%  10/22/99
%  ------------------------------------------------

if nargin == 0;
	mu = 0; sigma = 1; N = 100, NUseed = [];
elseif nargin == 1
	sigma = 1; N = 100; NUseed = [];
elseif nargin == 2
	N = 100; NUseed = [];
elseif nargin == 3
	NUseed = [];
end


%%% initialize ("seed") random number generator
if isempty(NUseed) == 1
  NUseed = zeros(1,2);
  NUseed(1) = sum(100*clock);
  NUseed(2) = sum(109*clock);
end

randn('seed',NUseed(1));
rand('seed',NUseed(2));

%%% use algorithm of MATLAB routine NORMRND
%%% function r = normrnd(mu,sigma,m,n);
X = randn(N,1).*sigma + mu;

%%% use algorithm of MATLAB routine UNIFRND to draw
%%% a random sample from a uniform distribtion in [1,N];
sample = 1 + (N-1).*rand(1,1);

%%% find random sample xi
xi = X(round(sample));
