function Vrat = RandVrat(n,vrmin,vrmax,dis)
%
% Vrat = RandVrat(n,vrmin,vrmax,dis) creates 
% a distribution of vr/vs-ratios between the 
% limiting values vrmin (~0.75) and vrmax (~0.95) 
%
% Input: n 	- number of new "randomized" vratio's
%	 vrmin	- minimum value for ratio rupture/shear velocity
%			default: vrmin = 0.75;
%	 vrmax	- maximum value for ratio rupture/shear velocity
%			default: vrmax = 0.95;
%	 dis	- string for distribution to use;
%		  'norm' for normal
%		  'unif' for uniform
%		  'tria' for triangular
%
% Output:Vrat	- vector of n possible Vratio's
%
% Written by Martin Mai (mmai@pangea.Stanford.EDU) 
% 05/05/98
% last change 06/21/2001
% ------------------------------------------------


%%% set default values
if nargin == 1;
	vrmin = 0.75; vrmax = 0.95; dis = 'norm';
elseif nargin == 2
	vrmax = 0.95; dis = 'norm';
elseif nargin == 3
	dis = 'norm';
end

vrm = mean([vrmin vrmax]);


%%% select distribution for random vr
if dis == 'norm'
   vr = normrnd(vrm,0.05,n,1);
elseif dis == 'unif'
   vr = unifrnd(vrmin,vrmax,n,1);
elseif dis == 'tria'
   %% create triangular distribution
   if n > 100; nbin = n/2;
   else nbin = 100; end
   nsamp = [1:1:nbin/2 (1+nbin/2) nbin/2:-1:1]';
   csum = cumsum(nsamp);

   %% setup velocities
   dv = (vrmax-vrmin)/(nbin+1);
   for i = 1:nbin+1
      vdis(i) = vrmin+(i-0.5)*dv;
   end

   %% pick numbers from a discrete uniform distribution
   N = unidrnd(sum(nsamp),n,1);

   %% extract the corresponding velocities
   for k = 1:n
     k1 = find(csum > N(k));
     k2 = find(csum < N(k)); 
     vr(k) = mean([vdis(k1(1)) vdis(k2(end))]);
   end

end

%%% check that values don't fall outside the given range
%%% of vrmin <= vr <= vrmax
%% [i,j] = find(vr >= vrmin & vr <= vrmax);
%% Vrat = vr(j);
%
%%% return only the requested number Vratio's
%% Vrat = vr(1:n)';
%% ----------------

%%% round to nearest 1/100
Vrat = round(vr*100)/100;


