function [Mo,Mw] = fmomentS(in,dx,dz,type)
%
%  function [Mo,Mw] = fmomentS(in,dx,dz,'type') 
%  calculates the moment of an event for a given 
%  slip distribution
%  
%  Input: in	- 2D-slip map
%	  dx,dz - sampling of slip map (assumed in km)
%	  type  - string for dyne-cm ('d') or Newton-meters ('n');
%
%  Output: Mo	- moment estimate, either in dyne-cm or N-m
%	   Mw 	- moment magnitude, as defined by Hanks & Kanamori
%
%  mmai, 02/18/2000
%  ----------------

if nargin == 1
  dx = 1; dz = 1; type = 'n';
elseif nargin == 2;
  dz = dx; type = 'n';
elseif nargin == 3
  type = 'n';
end

mu = 3*1e10;			% shear modulus = rigidity [N/m^2]


%%% alternative way to do it is to sum all elements
%%% and use the subfault-size as "weight"
s = sum(in(:)/100);

if type == 'd'

  Mo = mu*s*1e6*dx*dz*1e7;
  Mw = fMo2Mw(Mo);		% moment magnitude

elseif type == 'n'

  Mo = mu*s*1e6*dx*dz;
  Mw = fMo2MwN(Mo);		% moment magnitude

end
