function [S,xi,zi] = interpgrid2(data,Nout,meth)
%
%  [S,xi,zi] = INTERPGRID2(data,Nout,'meth')
%  interpolates gridded data onto a different sized
%  grid, or uses same grid size with finer sampling.
%  Useful for 2D-slip distributions on fault planes.
%	
%  INPUT: data 	- data input (2D-grid)
%	      Nout 	- dimension for output grid [z x]
%	      meth  - 'nearest' - nearest neighbor interpolation
%     		      'linear'  - bilinear interpolation (default)
%      		      'cubic'   - bicubic interpolation
%
%  OUTPUIT: S	- interpolated grid
%	   xi	- interpolated "axis" in x-direction
%	   zi 	- interpolated "axis" in z-direction
%
% See also INTERP2 from the MATLAB toolbox

%  Martin Mai, Dec 2002
%  ------------------------------------------------

if nargin <2; error('not enough arguments');
elseif nargin == 2
    meth = 'linear';
end

%%% input data sampling, creating mesh grids with appropriate intervals
[m,n] = size(data);
xl = [1:1:n];
zl = [1:1:m]';
[Z,X] = meshgrid(xl,zl);


%%% create finer grid based on user-given array size, i.e.
%%% new sampling is derived from old and new array dimensions
xi = linspace(1,n,Nout(2));
zi = linspace(1,m,Nout(1))';		
[ZI,XI] = meshgrid(xi,zi);


%%% interpolate grid, using specifed method, default is bilinear
S = interp2(Z,X,data,ZI,XI,meth);

