function [xax,zax]=plotslip2(slip,dim,hypo,htop,cb,nf);
%
% function plotslip2f(slip,dim,hypo,htop,'cb','nf')
% plots the slip distribution SLIP on the fault plane 
%
% INPUT: slip 	- 2D aray of slip values
%        dim    - dimension of rupture plane
%	 hypo 	- hypocenter coordinates [x z] w.r.t. fault plane
%	 htop 	- depth to top of fault plane
%	 cb	    - 'hor' or 'ver' for horizontal/vertical colorbar
%	 nf	    - 'y' if new figure window is desired, default 'y'
%
% mmai, 01/26/98 (mmai@pangea.Stanford.EDU)
% last change 08/18/99 (mmai)
% ----------------------------------------

%%% define default values in case no hypocenter or depth is given
if nargin == 1
  hypo = []; htop = 0; dim = size(slip); 
  cb = 'hor';  nf = 'y';
elseif nargin == 2
  htop = 0; hypo = []; 
  cb = 'off';  nf = 'y';
elseif nargin == 3;
  htop = 0; cb = 'hor';  nf = 'y';
elseif nargin == 4
  cb = 'hor'; nf = 'y';
elseif nargin == 5
  nf = 'y';
end

[lz,lx] = size(slip);
W = dim(1); L = dim(2);
dz = W/lz; 
dx = L/lx;

%%% calculate Mw,Mo for slip distribution
[Mo,Mw] = fmomentN(slip,dim); 

%%% set up axis
zax = linspace(htop,W+htop,lz);
xax = linspace(0,L,lx);

%%% plotting slip distribution

if nf == 'y';
 figure;
 a = axes('pos',[0.15 0.4 0.7 0.5]);
 set(a,'FontS',10,'LineW',1.5);
end


%% define contour intervals
%ci = floor(max(slip(:))/10);
%if ci >= 10
%    ci = 10*round(ci/10);
%elseif ci <=1 ; ci = 1;
%end
%cl = 0:ci:max(slip(:));

tstr1 = sprintf('M_w = %.2f (M_o = %.2e Nm)',Mw,Mo);
%%tstr2 = sprintf('(contour interval: %.1f cm)',ci);

%%contourf(xax,zax,slip,cl); 
pcha=imagesc(xax,zax,slip);
hold on;
axis equal; axis tight; axis ij;
xlabel('Along Strike Distance[km]','FontS',9);	
ylabel('Down Dip Distance [km]','FontS',9);			
title(tstr1,'FontS',11,'FontW','bo');
if isempty(hypo) == 0
  plot(hypo(1),hypo(2)+htop,'kp','MarkerS',18,'MarkerF','w'); 
end
hold off;


%%% plot customized colorbar
if cb ~= 'off'
 cbstr = sprintf('Slip [cm]');
if cb == 'hor'   
   %%% horizontal colorbar
   ch = colorbar('horiz');
   ips = get(get(pcha,'parent'),'pos');
   set(ch,'pos',[0.25 ips(2)-0.25 0.5 0.025]);
   chl = get(ch,'Xlabel'); 
   set(chl,'String',cbstr,'FontS',9);

elseif cb == 'ver'   
   %%% vertical colorbar
   ch = colorbar;
   ips = get(get(pcha,'parent'),'pos');
   set(ch,'pos',[ips(3)+0.1 ips(2) 0.025 ips(4)]);
   %set(ch,'pos',[0.85 ips(2) 0.035 ips(4)]);
   chl = get(ch,'Ylabel'); 
   set(chl,'String',cbstr,'FontS',9,'Rot',270,'Ver','bot');
end
end

