function S = resampgrid(data,Nout,par)
%
%  S = RESAMPGRID(data,Nout,par)
%  resamples gridded data onto a different sized
%  grid, or uses same grid size with finer sampling.
%  Useful for 2D-slip distributions on fault planes.
%	
%  input: data 	- data input (2D-grid)
%	  Nout 	- dimension for output grid [z x]
%         par   - structure to specify filter options
%                 par.nwin = 2  (default)
%                 par.beta = 5  (default)
%
%  THIS FUNCTION USES MATLAB's RESAMPLE ALGORITHM
%
%  output: S	- interpolated grid
%
%  See also RESAMP from the MATLAB toolbox

%  Written by Martin Mai, Nov 2002
%  ------------------------------------------------

if nargin <2; error('not enough arguments');
elseif nargin == 2
    par.nwin = 3; par.beta = 3;
end

%%% define new grid size
[m,n] = size(data);
Nout  = round(Nout);

dat1 = resample(data, Nout(1),m,par.nwin,par.beta);
S    = resample(dat1',Nout(2),n,par.nwin,par.beta)';
